@@ -75,18 +75,20 @@
 
 // Construct the main application window
 KWin4App::KWin4App(QWidget *parent)
-        : KXmlGuiWindow(parent), mView(0), mDoc(0), mMyChatDlg(0), mStatusMsg(nullptr), mStatusMover(nullptr)
+        : KXmlGuiWindow(parent),
+          mTheme(nullptr),
+          mView(nullptr),
+          mDoc(nullptr),
+          mScene(nullptr),
+          mColorGroup(nullptr),
+          mMyChatDlg(nullptr),
+          mStatusMsg(nullptr),
+          mStatusMover(nullptr)
 {
   // default names for players
   (void)I18N_NOOP2("default name of first player", "Player 1");
   (void)I18N_NOOP2("default name of second player", "Player 2");
 
-  mDoc       = 0;
-  mView      = 0;
-  mScene     = 0;
-  mTheme     = 0;
-  mMyChatDlg = 0;
-
   // Add resource type to grafix
   KGlobal::dirs()->addResourceType("kwin4theme", "appdata", "grafix/");
 
@@ -606,9 +608,9 @@ void KWin4App::askForHint()
 // Show statistics dialog
 void KWin4App::showStatistics()
 {
-  QDialog dlg(this);
+  QPointer<QDialog> dlg = new QDialog(this);
   Ui::Statistics ui;
-  ui.setupUi(&dlg);
+  ui.setupUi(dlg);
 
   ui.p1_name->setText(mDoc->getName(Yellow));
   ui.p1_won->display(mDoc->getStatistic(Yellow, TWin));
@@ -624,10 +626,11 @@ void KWin4App::showStatistics()
   ui.p2_aborted->display(mDoc->getStatistic(Red, TBrk));
   ui.p2_sum->display(mDoc->getStatistic(Red, TSum));
 
-  if(dlg.exec() == QDialog::Rejected)
+  if(dlg->exec() == QDialog::Rejected)
   {
     mDoc->resetStatistic();
   }
+  delete dlg;
 }
 
 
